@@ -212,6 +212,10 @@ make_label <- function (ht) {
 
   has_knitr <- requireNamespace("knitr", quietly = TRUE)
   chunk_label <- if (has_knitr) knitr::opts_current$get("label") else NULL
+  if (length(chunk_label) > 0 && grepl("^unnamed-chunk", chunk_label)) {
+    chunk_label <- NULL
+  }
+
   if (is.na(lab) &&
       getOption("huxtable.autolabel", TRUE) &&
       has_knitr &&
